@@ -1,12 +1,10 @@
 #
-# $Id: Simple.pm,v 1.4 2001/03/12 18:23:11 mpeppler Exp $
+# $Id: Simple.pm,v 1.7 2001/12/13 01:36:04 mpeppler Exp $
 #
-# Copyright (c) 1998-2000   Michael Peppler
+# Copyright (c) 1998-2001   Michael Peppler
 #
 #   You may distribute under the terms of either the GNU General Public
-#   License or the Artistic License, as specified in the Perl README file,
-#   with the exception that it cannot be placed on a CD-ROM or similar media
-#   for commercial distribution without the prior approval of the author.
+#   License or the Artistic License, as specified in the Perl README file.
 #
 
 package Sybase::Simple;
@@ -22,7 +20,7 @@ use Sybase::CTlib qw(:DEFAULT !ct_callback);
 
 @ISA = qw(Exporter AutoLoader Sybase::CTlib);
 @EXPORT = @Sybase::CTlib::EXPORT;
-$VERSION = '0.52';
+$VERSION = '0.54';
 
 my %CallBacks;
 
@@ -227,7 +225,7 @@ sub ArrayOfScalar {
 	# fetch one row as an array
 	while (my $d = $self->ct_fetch(0,1)) {
 	    # we're only interested in the first column of each result set
-		push(@$ret, $$d[0]);
+	    push(@$ret, $$d[0]);
 	}
     }
 
@@ -719,15 +717,13 @@ Michael Peppler, mpeppler@peppler.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 1998   Michael Peppler
+Copyright (c) 1998-2001   Michael Peppler
 
 You may distribute under the terms of either the GNU General Public
-License or the Artistic License, as specified in the Perl README file,
-with the exception that it cannot be placed on a CD-ROM or similar media
-for commercial distribution without the prior approval of the author.
+License or the Artistic License, as specified in the Perl README file.
 
 =head1 SEE ALSO
 
-perl(1), sybperl(3)
+perl(1), sybperl(3), Sybase::CTlib(3)
 
 =cut
